﻿using Steema.TeeChart.WPF;
using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Markup;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace WpfApplication1
{
  /// <summary>
  /// Interaction logic for MainWindow.xaml
  /// </summary>
  public partial class MainWindow : Window
  {
    public MainWindow()
    {
      InitializeComponent();
      InitializeChart();
    }

    TChart[] childCharts;
    const int childCount = 4;

    private void InitializeChart()
    {
      tChart1.Series.Add(new Steema.TeeChart.WPF.Styles.Bar()).FillSampleValues();

      childCharts = new TChart[childCount];

      for (int i = 0; i < childCount; i++)
      {
        Steema.TeeChart.WPF.TChart child = new Steema.TeeChart.WPF.TChart();

        child.Series.Add(new Steema.TeeChart.WPF.Styles.Pie()).FillSampleValues();

        child.Margin = new Thickness(i * 100, i * 50, 0, 0);
        child.Width = 500; 
        child.Height = 250; 
        tChart1.Children.Add(child);

        childCharts[i] = child;
      }

      tcCharts.SelectionChanged += new SelectionChangedEventHandler(tcCharts_SelectionChanged);

      docViewer.Document = CreateFixedDocumentWithPage();
    }

    void tcCharts_SelectionChanged(object sender, SelectionChangedEventArgs e)
    {
      IList list = e.AddedItems;
      if (list.Contains(tiSingleChart))
      {
        tChart1.Invalidate();
      }
      else if (list.Contains(tiPrintChart))
      {
        //tcWidth = tChart1.ActualWidth;
        //tcHeight = tChart1.ActualHeight;
        docViewer.Document = CreateFixedDocumentWithPage();
      }
    }

    public FixedDocument CreateFixedDocumentWithPage()
    {
      FixedDocument fixedDocument = CreateFixedDocument();

      for (int i = 0; i < childCount; i++)
      {
        PageContent pageContent = CreateFirstPageContent(childCharts[i]);
        fixedDocument.Pages.Add(pageContent);
      }

      return fixedDocument;
    }

    private FixedDocument CreateFixedDocument()
    {
      FixedDocument fixedDocument = new FixedDocument();
      fixedDocument.DocumentPaginator.PageSize = new Size(96 * 8.5, 96 * 11);
      return fixedDocument;
    }

    private PageContent CreateFirstPageContent(TChart chart)
    {
      PageContent pageContent = new PageContent();
      FixedPage fixedPage = new FixedPage();
      fixedPage.Background = Brushes.White;
      Canvas canvas1 = new Canvas();
      canvas1.Width = 8.5 * 96;
      canvas1.Height = 11 * 96;

      TextBlock label = new TextBlock();
      label.Foreground = Brushes.Black;
      label.FontFamily = new System.Windows.Media.FontFamily("Arial");
      label.FontSize = 24.0;
      label.Text = "TeeChart for .NET WPF Control Printing";
      label.InvalidateVisual();
      Canvas.SetTop(label, 200);
      Canvas.SetLeft(label, (canvas1.Width / 2.0) - (200));
      canvas1.Children.Add(label);
      
      DrawingVisual d = new DrawingVisual();
      DrawingContext g = d.RenderOpen();
      chart.Draw(g);

      AdornerLayer parent = AdornerLayer.GetAdornerLayer(tChart1);
      if (parent != null)
      {
        Adorner[] adorners = parent.GetAdorners(chart);
        if (adorners != null)
        {
          foreach (TeeAdorner item in adorners)
          {
            item.Draw(g);
          }
        }
      }
      g.Close();

      Rectangle chartRect = new Rectangle();
      VisualBrush vBrush = new VisualBrush(d);
      double ratio = chart.ActualHeight / chart.ActualWidth;
      chartRect.Width = 500;
      chartRect.Height = 500 * ratio;
      chartRect.Fill = vBrush;
      Canvas.SetTop(chartRect, 400);
      Canvas.SetLeft(chartRect, (canvas1.Width / 2.0) - (250));
      canvas1.Children.Add(chartRect);


      fixedPage.Children.Add(canvas1);

      double pageWidth = 96 * 8.5;
      double pageHeight = 96 * 11;
      fixedPage.Width = pageWidth;
      fixedPage.Height = pageHeight;

      ((IAddChild)pageContent).AddChild(fixedPage);
      return pageContent;
    }

  }
}
